import numpy as np
import matplotlib.pyplot as plt

# Apply style BEFORE creating figures
plt.style.use('./cepc_style.mplstyle')

def example_draw_plot():
  # This example draws a simple line plot with two curves,
  # and adds some text annotations for the CEPC Ref-TDR, luminosity, and energy.

  # Create some data
  x = np.linspace(0, 2*np.pi, 100)
  y1 = np.sin(x)
  y2 = np.cos(x)

  # Draw the plot
  fig, ax = plt.subplots(figsize=(10, 7.5))
  ax.plot(x, y1, lw=3, color='orangered', label='sin(x)')
  ax.plot(x, y2, lw=3, color='royalblue', label='cos(x)')

  # Set the x and y axis labels
  ax.set_xlabel('X Label')
  ax.set_ylabel('Y Label')
  # Or you can choose the set x label in the right side and y label in the top side
  # ax.set_xlabel('X Label', loc='right')
  # ax.set_ylabel('Y Label', loc='top')

  # Add legend if needed
  plt.legend(loc='lower left', fontsize=25)

  ## Add "CEPC Ref-TDR" (bold) on the top left corner if needed
  ax.text(0.0, 1.05, r"$\mathbf{CEPC}$ Ref-TDR", 
          transform=ax.transAxes, fontsize=20, ha='left', va='top',
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))
  ## Add luminosity and energy on the top right corner if needed
  ax.text(1, 1.05, r"5.6 ab$^{-1}$, 240 GeV", 
          transform=ax.transAxes, fontsize=20, ha='right', va='top',
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))
  
  # Save the figure in vector format
  fig.savefig('./sample_figures/example_plot.pdf', bbox_inches='tight')

  # Show the figure
  plt.show()

def example_draw_hist():
  # This example draws two histograms with different data sets,
  # and adds some text annotations for the CEPC Ref-TDR, luminosity, and energy.

  # Create some data
  x1 = np.random.normal(0, 1, 10000)
  x2 = np.random.normal(1, 2, 10000)

  # Draw the histogram
  fig, ax = plt.subplots(figsize=(10, 7.5))
  ax.hist(x1, bins=100, range=(-5, 5), histtype='step', lw=3)
  ax.hist(x2, bins=100, range=(-5, 5), histtype='step', lw=3)

  # Set the x and y axis labels
  ax.set_xlabel('X Label')
  ax.set_ylabel('Y Label')
  # Or you can choose the set x label in the right side and y label in the top side
  # ax.set_xlabel('X Label', loc='right')
  # ax.set_ylabel('Y Label', loc='top')
  
  ## Add "CEPC Ref-TDR" on the top left corner if needed
  ax.text(0.00, 1.05, r"$\mathbf{CEPC}$ Ref-TDR", 
          transform=ax.transAxes, fontsize=20, ha='left', va='top', 
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))
  ## Add luminosity and energy on the top right corner if needed
  ax.text(1, 1.05, r"5.6 ab$^{-1}$, 240 GeV", 
          transform=ax.transAxes, fontsize=20, ha='right', va='top',
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))

  # Save the figure in vector format
  fig.savefig('./sample_figures/example_hist.pdf', bbox_inches='tight')

  # Show the figure
  plt.show()

def example_draw_hist2d():
  # This example draws a 2-dimentional histogram with two data sets,
  # and adds some text annotations for the CEPC Ref-TDR, luminosity, and energy.


  # Create some data
  x = np.random.normal(0, 1, 10000)
  y = np.random.normal(0, 1, 10000)
  fig, ax = plt.subplots(figsize=(10, 7.5))
  ax.hist2d(x, y, bins=(100, 100), range=[[-5, 5], [-5, 5]], cmin=0.99, cmap='viridis')

  # Set the x and y axis labels
  ax.set_xlabel('X Label')
  ax.set_ylabel('Y Label')
  # Or you can choose the set x label in the right side and y label in the top side
  # ax.set_xlabel('X Label', loc='right')
  # ax.set_ylabel('Y Label', loc='top')

  # Add colorbar if needed
  cbar = plt.colorbar(ax.collections[0], ax=ax)
  cbar.set_label('Entries')
  
  ## Add "CEPC Ref-TDR" on the top left corner if needed
  ax.text(0.00, 1.05, r"$\mathbf{CEPC}$ Ref-TDR", 
          transform=ax.transAxes, fontsize=20, ha='left', va='top', 
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))
  ## Add luminosity and energy on the top right corner if needed
  ax.text(1, 1.05, r"5.6 ab$^{-1}$, 240 GeV", 
          transform=ax.transAxes, fontsize=20, ha='right', va='top',
          bbox=dict(facecolor='white', alpha=0, edgecolor='none'))

  # Save the figure in vector format
  fig.savefig('./sample_figures/example_hist2d.pdf', bbox_inches='tight')

  # Show the figure
  plt.show()

example_draw_plot()
example_draw_hist()
example_draw_hist2d()


